/// <reference types="node" />
interface Ref<T> {
    readonly current: T | null;
}
export declare enum VideoPixelFormatEnum {
    I420 = 0,
    Nv12 = 1,
    Rgba = 2
}
export interface VideoFrameSource {
    /**
     * Copies the latest frame into `buffer`.
     *
     * Note that `maxWidth` and `maxHeight` specify maximum dimensions,
     * but allow for rotation, i.e. a maximum of 1920x1080 will also allow
     * portrait-mode 1080x1920.
     *
     * Returns a `[width, height]` pair for the resulting frame,
     * or `undefined` if there's no new frame ready to be displayed.
     */
    receiveVideoFrame(buffer: Buffer, maxWidth: number, maxHeight: number): [number, number] | undefined;
}
interface VideoFrameSender {
    sendVideoFrame(width: number, height: number, format: VideoPixelFormatEnum, buffer: Buffer): void;
}
export declare class GumVideoCaptureOptions {
    maxWidth: number;
    maxHeight: number;
    maxFramerate: number;
    preferredDeviceId?: string;
    screenShareSourceId?: string;
}
export declare class GumVideoCapturer {
    private defaultCaptureOptions;
    private localPreview?;
    private captureOptions?;
    private sender?;
    private mediaStream?;
    private spawnedSenderRunning;
    private preferredDeviceId?;
    private updateLocalPreviewIntervalId?;
    constructor(defaultCaptureOptions: GumVideoCaptureOptions);
    capturing(): boolean;
    setLocalPreview(localPreview: Ref<HTMLVideoElement> | undefined): void;
    enableCapture(): void;
    enableCaptureAndSend(sender: VideoFrameSender, options?: GumVideoCaptureOptions): void;
    disable(): void;
    setPreferredDevice(deviceId: string): Promise<void>;
    enumerateDevices(): Promise<Array<MediaDeviceInfo>>;
    private getUserMedia;
    private startCapturing;
    private stopCapturing;
    private startSending;
    private spawnSender;
    private stopSending;
    private updateLocalPreviewSourceObject;
}
export declare const MAX_VIDEO_CAPTURE_WIDTH: number;
export declare const MAX_VIDEO_CAPTURE_HEIGHT: number;
export declare const MAX_VIDEO_CAPTURE_AREA: number;
export declare const MAX_VIDEO_CAPTURE_BUFFER_SIZE: number;
export declare class CanvasVideoRenderer {
    private canvas?;
    private buffer;
    private imageData?;
    private source?;
    private rafId?;
    constructor();
    setCanvas(canvas: Ref<HTMLCanvasElement> | undefined): void;
    enable(source: VideoFrameSource): void;
    disable(): void;
    private requestAnimationFrameCallback;
    private renderBlack;
    private renderVideoFrame;
}
export {};
